# ARKimedes

## Introduction

ARKimedes is a Python library to automate ARK-related workflows at Iowa State
University's Parks Library.

This software is at an early stage of development and may be subject to
significant changes from update to update.
